==> dcl_7.4.5.orig.tar.gz: dcl-7.4.5/src/misc2/f90src/f90/rfalib.f90 <==
!-------------------------------------------------
!  RFAlib Module
!-------------------------------------------------
module rfalib
  use dcl_common
  contains

    function DclGetAVE(x)                        !ʿѤ
      real, intent(in), dimension(:) :: x
      real                           :: DclGetAVE

      call prcopn('DclGetAVE')
      DclGetAVE = rave(x,size(x),1)
      call prccls('DclGetAVE')
    end function
      
    function DclGetVAR(x)                        !ʬ
      real, intent(in), dimension(:) :: x
      real                           :: DclGetVAR

      call prcopn('DclGetVAR')
      DclGetVAR = rvar(x,size(x),1)
      call prccls('DclGetVAR')
    end function
      
    function DclGetSTD(x)                        !ɸк
      real, intent(in), dimension(:) :: x
      real                           :: DclGetSTD

      call prcopn('DclGetSTD')
      DclGetSTD = rstd(x,size(x),1)
      call prccls('DclGetSTD')
    end function
      
    function DclGetRMS(x)                        !root mean square
      real, intent(in), dimension(:) :: x
      real                           :: DclGetRMS

      call prcopn('DclGetRMS')
      DclGetRMS = rrms(x,size(x),1)
      call prccls('DclGetRMS')
    end function
      
    function DclGetAMP(x)                        !礭 (ʦ x^2)^1/2 ) 
      real, intent(in), dimension(:) :: x
      real                           :: DclGetAMP

      call prcopn('DclGetAMP')
      DclGetAMP = ramp(x,size(x),1)
      call prccls('DclGetAMP')
    end function
end module

==> dcl_7.5.1.orig.tar.gz: dcl-7.5.1/src/misc2/f90src/f90/rfalib.f90 <==
!-------------------------------------------------
!  RFAlib Module
!-------------------------------------------------
module rfalib
  use dcl_common
  contains

    function DclGetAVE(x)                        !平均を求める
      real, intent(in), dimension(:) :: x
      real                           :: DclGetAVE

      call prcopn('DclGetAVE')
      DclGetAVE = rave(x,size(x),1)
      call prccls('DclGetAVE')
    end function
      
    function DclGetVAR(x)                        !分散を求める
      real, intent(in), dimension(:) :: x
      real                           :: DclGetVAR

      call prcopn('DclGetVAR')
      DclGetVAR = rvar(x,size(x),1)
      call prccls('DclGetVAR')
    end function
      
    function DclGetSTD(x)                        !標準偏差を求める
      real, intent(in), dimension(:) :: x
      real                           :: DclGetSTD

      call prcopn('DclGetSTD')
      DclGetSTD = rstd(x,size(x),1)
      call prccls('DclGetSTD')
    end function
      
    function DclGetRMS(x)                        !root mean squareを求める
      real, intent(in), dimension(:) :: x
      real                           :: DclGetRMS

      call prcopn('DclGetRMS')
      DclGetRMS = rrms(x,size(x),1)
      call prccls('DclGetRMS')
    end function
      
    function DclGetAMP(x)                        !大きさ (（Σ x^2)^1/2 ) を求める
      real, intent(in), dimension(:) :: x
      real                           :: DclGetAMP

      call prcopn('DclGetAMP')
      DclGetAMP = ramp(x,size(x),1)
      call prccls('DclGetAMP')
    end function
end module
